#!/bin/bash
#
# /etc/init.d/tomcat5.5 -- startup script for the Tomcat 5 servlet engine customixed
# for Metacat
#
# Written by Michael Daigle <daigle@nceas.ucsb.edu>.
#

DESC="Tomcat servlet engine"
export JAVA_HOME=/usr/lib/jvm/java-1.5.0-sun
export CATALINA_HOME=/usr/share/tomcat5.5

if [ `id -u` -ne 0 ]; then
	echo "You need root privileges to run this script"
	exit 1
fi
         
# Make sure tomcat is started with system locale
if [ -r /etc/default/locale ]; then
	. /etc/default/locale
	export LANG
fi

. /lib/lsb/init-functions
. /etc/default/rcS

function start {
	if [ -z "$JAVA_HOME" ]; then
		log_failure_msg "no JDK found - please set JAVA_HOME"
		exit 1
	fi

	if [ ! -d "$CATALINA_HOME/conf" ]; then
		log_failure_msg "invalid CATALINA_HOME specified"
		exit 1
	fi

	log_daemon_msg "Starting $DESC" 
	$CATALINA_HOME/bin/startup.sh
	log_end_msg 0
}  

function stop {
	log_daemon_msg "Stopping $DESC"
	$CATALINA_HOME/bin/shutdown.sh
	log_end_msg 0
}
	
case "$1" in
  start)
	start
	;;
  stop)
	stop
	;;
  restart|force-reload)
	stop
	sleep 5
	start
	;;
  *)
	log_success_msg "Usage: $0 {start|stop|restart}"
	exit 1
	;;
esac

exit 0
